@@ -16,7 +16,8 @@ use warnings;
 use strict;
 
 use vars qw(@EXPORT @ISA @rl_History $rl_HistoryIndex $rl_history_length
-            $rl_MaxHistorySize $rl_max_input_history $history_stifled);
+            $rl_MaxHistorySize $rl_max_input_history $history_base
+            $history_stifled);
 
 @ISA = qw(Exporter);
 @EXPORT  = qw(@rl_History $rl_HistoryIndex $rl_history_length
@@ -29,6 +30,7 @@ $rl_history_length = 0;
 $rl_max_input_history = 0;
 
 $history_stifled = 0;
+$history_base    = 0;
 
 =head2 add_line_to_history
 
